﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using System.IO;

namespace Sharp_Piano_Player
{
    public partial class MainForm : Form
    {
        private string[] _words;
        private int _index;
        private string[] _filePaths;
        private int _countDown = 3;
        private bool _starting = false;

        public MainForm()
        {
            InitializeComponent();
            PopulateSongComboBox();
            _words = textBox.GetNotes();
        }

        private void PopulateSongComboBox()
        {
            try
            {
                _filePaths = Directory.GetFiles("Songs");

                foreach (string path in _filePaths)
                {
                    comboSongList.Items.Add(Path.GetFileNameWithoutExtension(path));
                }
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, Application.ProductName, MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }

        private void timer_Tick(object sender, EventArgs e)
        {
            if (_index == _words.Length - 1)
            {
                _index = 0;
                Stop();
            }

            string note = _words[_index];
            SendKeys.Send(note);
            _index++;
            lblKeys.Text = note;
        }

        protected override void OnClosing(CancelEventArgs e)
        {
            timer.Stop();
            base.OnClosing(e);
        }

        protected override void OnMouseEnter(EventArgs e)
        {
            this.Select();

            if (!_starting)
            {
                Stop();
            }
        }

        private void Stop()
        {
            this.Select();
            timer.Stop();
            btnPlay.Enabled = true;
            nudInterval.Enabled = true;
            btnPlay.Text = "Play";
            textBox.Enabled = true;
            _index = 0;
        }

        private void nudInterval_ValueChanged(object sender, EventArgs e)
        {
            timer.Interval = (int)nudInterval.Value;
        }

        private void btnLoad_Click(object sender, EventArgs e)
        {
            try
            {
                int index = comboSongList.SelectedIndex;
                textBox.Text = File.ReadAllText(_filePaths[index]);
                _words = textBox.GetNotes();
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, Application.ProductName, MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }

        private void btnPlay_Click(object sender, EventArgs e)
        {
            _words = textBox.GetNotes();
            _starting = true;
            nudInterval.Enabled = false;
            btnPlay.Enabled = false;
            textBox.Enabled = false;
            tmrCountDown.Start();
        }

        private void tmrCountDown_Tick(object sender, EventArgs e)
        {
            btnPlay.Text = _countDown.ToString();

            if (_countDown == 1)
            {
                tmrCountDown.Stop();
                _countDown = 3;
                timer.Start();
                _starting = false;
            }
            else
            {
                _countDown--;
            }
        }
    }
}